# Form Render

## Add to project

```
yarn add mv-form-render
```

## Use

```
<template>
  <form-render :config-url="configUrl" :config-token="configToken" @submission="handleSubmission"></form-render>
</template>

<script>
import FormRender from "mv-form-render";
export default {
  components: { FormRender },
  data: () => ({
    configUrl:
      "http://*.*.global:4001/form/60366ec8b5842c0b48a78d72",
    configToken:
      "dkjsadhsaghjryeryi2bk_fdhsjkfh37"
  }),
  methods: {
    handleSubmission(e) {
      console.log(e);
    },
  },
};
</script>
```

## Add new type field

## Setup Form Builder Field
### Add General Field Type
Dalam menambahkan Field Type melibatkan 3 bagian yaitu:
* Backend - Berfungsi sebagai repository untuk melakukan POST (Create) Field Type
* Admin : Berfungsi sebagai repository untuk menambahkan *Identifier* dan *properties* pada Field Type
* Render : Berfungsi sebagai repository untuk menambahkan *components* pada Field Type

![image](diagram-new-field-type.png)

Langkah yang dilakukan untuk menambahkan Field Type pada Form Builder adalah sebagai berikut:
* Buka Backend melalui dokumentasi berikut http://backbone.machinevision.global:4100/api/
* Pada Field-Type, Pilih POST /form-builder/api/field-type

* Tulis *request body* berisi *identifier*, *name*, *description*, dan *properties*
```sh
{
  "identifier": "Text",
  "name": "Texting",
  "description": "Test",
  "properties": null
}
```
* Selanjutnya pindah pada sisi Admin (Frontend), tambahkan *identifier* pada file MvFormBuilderField.vue di lokasi direktori components/MvFormBuilder
```sh
......
<v-flex v-if="type">
      <v-text-field
        v-if="type.identifier === 'text'"
        solo
        :placeholder="decorator.placeholder"
        :prefix="decorator.prefix"
        :prepend-icon="decorator.prependIcon"
        :append-icon="decorator.appendIcon"
        :dense="decorator.dense"
        readonly
      ></v-text-field>
      //INPUT IDENTIFIER BARU DISINI
      <v-text-field
        v-else-if="type.identifier === 'number'"
        :value="1234"
        type="number"
        solo
        :dense="decorator.dense"
        :placeholder="decorator.placeholder"
        readonly
      ></v-text-field>
></v-text-field>
.....
```
* Selanjutnya tambahkan *properties* pada file MvFormBuilderFieldProperties.vue di direktori components/MvFormBuilder
```sh
.....
   <v-text-field
            v-if="textEditor[0] === 'size'"
            :value="size"
            solo
            placeholder="Enter size text..."
            @change="updateSize"
          ></v-text-field>
          // INPUT PROPERTIES BARU DISINI
          <v-select
            v-else-if="textEditor[0] === 'style'"
            :value="style"
            :items="styles"
            solo
            placeholder="Select font style text"
            @change="updateStyle"
          ></v-select>
.......
```
* Kemudian berpindah pada bagian Render, Tambahkan *Component* pada file FieldRender.vue di direktori components/
```sh
.....
   <field-text
        v-if="identifier === 'text'"
        v-model="inputVal"
        :properties="properties"
      ></field-text>
      //INPUT COMPONENT BARU DISINI
      <field-number
        v-else-if="identifier === 'number'"
        v-model="inputVal"
        :properties="properties"
      ></field-number>
....
```